==> apache-felix-karaf-1.0.0-src.zip: apache-felix-karaf-1.0.0/src/shell/commands/src/main/java/org/apache/felix/karaf/shell/commands/SleepAction.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.felix.karaf.shell.commands;

import org.apache.felix.karaf.shell.console.OsgiCommandSupport;
import org.apache.felix.gogo.commands.Argument;
import org.apache.felix.gogo.commands.Command;

@Command(scope = "shell", name = "sleep", description = "Sleep for a bit then wake up")
public class SleepAction extends OsgiCommandSupport {

    @Argument(required=true)
    private int time = -1;

    protected Object doExecute() throws Exception {
        log.info("Sleeping for {}", time);

        try {
            Thread.sleep(time);
        }
        catch (InterruptedException ignore) {
            log.debug("Sleep was interrupted... :-(");
        }

        log.info("Awake now");
        return null;
    }
}

==> apache-felix-karaf-1.6.0-src.zip: apache-felix-karaf-1.6.0/src/shell/commands/src/main/java/org/apache/felix/karaf/shell/commands/SleepAction.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.felix.karaf.shell.commands;

import org.apache.felix.karaf.shell.console.OsgiCommandSupport;
import org.apache.felix.gogo.commands.Argument;
import org.apache.felix.gogo.commands.Command;

@Command(scope = "shell", name = "sleep", description = "Sleeps for a bit then wakes up")
public class SleepAction extends OsgiCommandSupport {

    @Argument(index = 0, name = "duration", description = "The amount of millis to sleep", required = true, multiValued = false)
    private long time = -1;

    protected Object doExecute() throws Exception {
        log.info("Sleeping for {}", time);

        try {
            Thread.sleep(time);
        }
        catch (InterruptedException ignore) {
            log.debug("Sleep was interrupted... :-(");
        }

        log.info("Awake now");
        return null;
    }
}
